==> sqlitedbms-0.2.0.tar.gz: sqlitedbms-0.2.0/src/htdocs/client/js/boxTabMenu.js <==
function boxTabMenuProc(mdi, type, tab) {
	if (!mdi) return;
	if (mdi.grid && mdi.grid.dataset && mdi.grid.dataset.menu && mdi.divTabMenu.firstChild == mdi.grid.dataset.menu)
		mdi.divTabMenu.removeChild(mdi.divTabMenu.firstChild);
	switch (tab) {
		case 'Fields':
			if (type == 'table')
				mdi.divTabMenu.innerHTML='<a onclick="boxTabMenuAction(this, \'addcolumn\')">Add column</a> | <a onclick="boxTabMenuAction(this, \'refresh\')">Refresh</a>';
			else
				mdi.divTabMenu.innerHTML='<a onclick="boxTabMenuAction(this, \'refresh\')">Refresh</a>';
		break;
		case 'Indices':
			mdi.divTabMenu.innerHTML='<a onclick="boxTabMenuAction(this, \'addindex\')">Add Index</a>';
		break;
		case 'Index':
			mdi.divTabMenu.innerHTML='<a onclick="boxTabMenuAction(this, \'editindex\')">Edit Index</a>';
		break;
		case 'Triggers':
			mdi.divTabMenu.innerHTML='<a onclick="boxTabMenuAction(this, \'addtrigger\')">Add Trigger</a>';
		break;
		case 'Data':
			mdi.divTabMenu.innerHTML='';
			if (mdi.grid && mdi.grid.dataset && mdi.grid.dataset.menu)
				mdi.divTabMenu.appendChild(mdi.grid.dataset.menu);
		break;
		case 'Script':
			mdi.divTabMenu.innerHTML='<a onclick="boxTabMenuAction(this, \'edittrigger\')">Edit Trigger</a>';
		break;
		case 'SQL':
			mdi.divTabMenu.innerHTML='<a onclick="boxTabMenuAction(this, \'highright\')">Syntax highright</a> | <a onclick="boxTabMenuAction(this, \'execute\')">Execute</a>';
		break;
		case 'Explain':
			mdi.divTabMenu.innerHTML='<a href="http://www.sqlite.org/opcode.html" target="_blank">SQLite VM opcodes</a>';
		break;
		default:
			mdi.divTabMenu.innerHTML='';
		break;
	}
}

function boxTabMenuAction(link, action, value) {
	if (!link) return;
	var row=oFindParentByTagName(link, 'TR');
	var div=oFindParentById(link, 'box');
	if (!div) return;
	var mdi=div.box;
	if (!mdi) return;

	switch (action) {
		case 'addcolumn':	inspectorTableAddColumn(mdi.data);	break;
		case 'refresh':
			var tab=mdi.tab[mdi.selectedTab];
			if (!tab) return;
			switch (mdi.selectedTab) {
				case 'Fields':
					while (tab.childNodes.length > 0)
						tab.removeChild(tab.childNodes[0]);
					boxTabProc(mdi);
				break;
			}
		break;
		case 'addindex':
			inspectorIndexNew(mdi.data);
		break;
		case 'editindex':
			inspectorIndexModify(mdi.data);
		break;
		case 'addtrigger':
			inspectorTriggerNew(mdi.data);
		break;
		case 'edittrigger':
			inspectorTriggerModify(mdi.data);
		break;
		case 'reindex':
			if (row && row.data)
				inspectorIndexRebuild(row.data);
		break;
		case 'drop':
			if (row && row.data)
				inspectorDrop(row.data);
		break;
		case 'open':
			if (row && row.data)
				boxShow(row.data);
		break;
		case 'grid':
			if (mdi.grid && mdi.grid.dataset)
				mdi.grid.dataset.switchAction(value);
		break;
		case 'highright':
			var tab=mdi.tab[mdi.selectedTab];
			if (!tab || !tab.firstChild || tab.firstChild.tagName != 'IFRAME') return;
			syntaxSQL(tab.firstChild.contentWindow.document.body);
		break;
		case 'execute':
			var tab=mdi.tab[mdi.selectedTab];
			if (!tab || !tab.firstChild || tab.firstChild.tagName != 'IFRAME') return;
			var sql=innerText(tab.firstChild.contentWindow.document.body);
			if (sql) boxDbExec(mdi, sql, 'execute');
		break;
	}
}

==> sqlitedbms-0.3.0.tar.gz: sqlitedbms-0.3.0/src/htdocs/client/js/boxTabMenu.js <==
function boxTabMenuProc(mdi, type, tab) {
	if (!mdi) return;
	if (mdi.grid && mdi.grid.dataset && mdi.grid.dataset.menu && mdi.divTabMenu.firstChild == mdi.grid.dataset.menu)
		mdi.divTabMenu.removeChild(mdi.divTabMenu.firstChild);
	switch (tab) {
		case 'Fields':
			if (type == 'table')
				mdi.divTabMenu.innerHTML='<a onclick="boxTabMenuAction(this, \'addcolumn\')">Add column</a> | <a onclick="boxTabMenuAction(this, \'refresh\')">Refresh</a>';
			else
				mdi.divTabMenu.innerHTML='<a onclick="boxTabMenuAction(this, \'refresh\')">Refresh</a>';
		break;
		case 'Indices':
			mdi.divTabMenu.innerHTML='<a onclick="boxTabMenuAction(this, \'addindex\')">Add Index</a>';
		break;
		case 'Index':
			mdi.divTabMenu.innerHTML='<a onclick="boxTabMenuAction(this, \'editindex\')">Edit Index</a>';
		break;
		case 'Triggers':
			mdi.divTabMenu.innerHTML='<a onclick="boxTabMenuAction(this, \'addtrigger\')">Add Trigger</a>';
		break;
		case 'Data':
			mdi.divTabMenu.innerHTML='';
			if (mdi.grid && mdi.grid.dataset && mdi.grid.dataset.menu)
				mdi.divTabMenu.appendChild(mdi.grid.dataset.menu);
		break;
		case 'Script':
			mdi.divTabMenu.innerHTML='<a onclick="boxTabMenuAction(this, \'edittrigger\')">Edit Trigger</a>';
		break;
		case 'SQL':
			mdi.divTabMenu.innerHTML='<a onclick="boxTabMenuAction(this, \'highright\')">Syntax highright</a> | <a onclick="boxTabMenuAction(this, \'execute\')">Execute</a>';
		break;
		case 'Explain':
			mdi.divTabMenu.innerHTML='<a href="http://www.sqlite.org/opcode.html" target="_blank">SQLite VM opcodes</a>';
		break;
		default:
			mdi.divTabMenu.innerHTML='';
		break;
	}
}

function boxTabMenuAction(link, action, value) {
	if (!link) return;
	var row=oFindParentByTagName(link, 'TR');
	var div=oFindParentById(link, 'box');
	if (!div) return;
	var mdi=div.box;
	if (!mdi) return;

	switch (action) {
		case 'addcolumn':	inspectorTableAddColumn(mdi.data);	break;
		case 'refresh':
			var tab=mdi.tab[mdi.selectedTab];
			if (!tab) return;
			switch (mdi.selectedTab) {
				case 'Fields':
					while (tab.childNodes.length > 0)
						tab.removeChild(tab.childNodes[0]);
					boxTabProc(mdi);
				break;
			}
		break;
		case 'addindex':
			inspectorIndexNew(mdi.data);
		break;
		case 'editindex':
			inspectorIndexModify(mdi.data);
		break;
		case 'addtrigger':
			inspectorTriggerNew(mdi.data);
		break;
		case 'edittrigger':
			inspectorTriggerModify(mdi.data);
		break;
		case 'reindex':
			if (row && row.data)
				inspectorIndexRebuild(row.data);
		break;
		case 'drop':
			if (row && row.data)
				inspectorDrop(row.data);
		break;
		case 'open':
			if (row && row.data)
				boxShow(row.data);
		break;
		case 'grid':
			if (mdi.grid && mdi.grid.dataset)
				mdi.grid.dataset.switchAction(value, link);
		break;
		case 'highright':
			var tab=mdi.tab[mdi.selectedTab];
			if (!tab || !tab.firstChild || tab.firstChild.tagName != 'IFRAME') return;
			syntaxSQL(tab.firstChild.contentWindow.document.body);
		break;
		case 'execute':
			var tab=mdi.tab[mdi.selectedTab];
			if (!tab || !tab.firstChild || tab.firstChild.tagName != 'IFRAME') return;
			var sql=tab.firstChild.contentWindow.document.body.innerHTML.replace(/<br>|<p>/ig, '\n').replace(/<[^>]*>/g, '').replace(/&nbsp;/g, ' ').replace(/&lt;/g, '<').replace(/&gt;/g, '>');
			if (sql) boxDbExec(mdi, 'BEGIN;'+sql+'COMMIT;', 'execute');
		break;
	}
}
